@@ -14,7 +14,6 @@
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 # Copyright (C) 2010-2018 Dominik Kriegner <dominik.kriegner@gmail.com>
-from __future__ import division
 
 import copy
 import io
@@ -23,7 +22,6 @@ import operator
 import os
 import re
 import shlex
-import warnings
 
 import numpy
 import scipy.optimize
@@ -33,12 +31,6 @@ from . import elements
 from . import spacegrouplattice as sgl
 from . import wyckpos
 
-# python 2to3 compatibility
-try:
-    basestring
-except NameError:
-    basestring = str
-
 re_data = re.compile(r"^data_", re.IGNORECASE)
 re_loop = re.compile(r"^loop_", re.IGNORECASE)
 re_symop = re.compile(r"^\s*("
@@ -537,7 +529,7 @@ class CIFDataset(object):
                 self.sgrp_suf = sgl.get_possible_sgrp_suf(self.sgrp_nr)
             else:
                 self.sgrp_suf = ''
-        if isinstance(self.sgrp_suf, basestring):
+        if isinstance(self.sgrp_suf, str):
             suffixes = [self.sgrp_suf, ]
         else:
             suffixes = copy.copy(self.sgrp_suf)
